@@ -1,14 +1,14 @@
 package Markdent::Handler::HTMLStream::Document;
-BEGIN {
-  $Markdent::Handler::HTMLStream::Document::VERSION = '0.17';
+{
+  $Markdent::Handler::HTMLStream::Document::VERSION = '0.18';
 }
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
 use Markdent::Types qw( Str );
 
-use namespace::autoclean;
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
@@ -61,7 +61,7 @@ Markdent::Handler::HTMLStream::Document - Turns Markdent events into a complete
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -83,12 +83,18 @@ The title of the document. This is required.
 
 =item * output => $fh
 
-The file handle to which HTML output will be streamed. If you want to capture
-the output in a string, you can open a filehandle to a string:
+The file handle or object to which HTML output will be streamed. If you want
+to capture the output in a string, you can open a filehandle to a string:
 
   my $buffer = q{};
   open my $fh, '>', \$buffer;
 
+If you pass a file handle (or L<IO::Handle> object), then all calls to
+C<print()> will be checked, and an error will be thrown.
+
+You can pass an object of any other class, it must implement its own
+C<print()> method, and error handling is left up to this method.
+
 =back
 
 =head1 ROLES
