@@ -1,22 +1,22 @@
 package Markdent::Parser;
-BEGIN {
-  $Markdent::Parser::VERSION = '0.17';
+{
+  $Markdent::Parser::VERSION = '0.18';
 }
 
 use strict;
 use warnings;
+use namespace::autoclean 0.09;
 
-use Class::MOP;
+use Class::Load qw( load_optional_class );
 use Markdent::Dialect::Standard::BlockParser;
 use Markdent::Dialect::Standard::SpanParser;
 use Markdent::Types qw( Str HashRef BlockParserClass SpanParserClass );
 use MooseX::Params::Validate qw( validated_list );
 use Try::Tiny;
 
-use namespace::autoclean;
-use Moose;
-use MooseX::SemiAffordanceAccessor;
-use MooseX::StrictConstructor;
+use Moose 0.92;
+use MooseX::SemiAffordanceAccessor 0.05;
+use MooseX::StrictConstructor 0.08;
 
 with 'Markdent::Role::AnyParser';
 
@@ -70,7 +70,7 @@ sub BUILD {
 
     my %sp_args;
     for my $key (
-        grep {defined}
+        grep { defined }
         map  { $_->init_arg() }
         $self->_span_parser_class()->meta()->get_all_attributes()
         ) {
@@ -81,11 +81,11 @@ sub BUILD {
 
     $sp_args{handler} = $self->handler();
 
-    $self->_set_span_parser_args(\%sp_args);
+    $self->_set_span_parser_args( \%sp_args );
 
     my %bp_args;
     for my $key (
-        grep {defined}
+        grep { defined }
         map  { $_->init_arg() }
         $self->_block_parser_class()->meta()->get_all_attributes()
         ) {
@@ -94,15 +94,15 @@ sub BUILD {
             if exists $args->{$key};
     }
 
-    $bp_args{handler} = $self->handler();
+    $bp_args{handler}     = $self->handler();
     $bp_args{span_parser} = $self->_span_parser();
 
-    $self->_set_block_parser_args(\%bp_args);
+    $self->_set_block_parser_args( \%bp_args );
 }
 
 sub _set_classes_for_dialect {
-    my $self    = shift;
-    my $args    = shift;
+    my $self = shift;
+    my $args = shift;
 
     my $dialect = delete $args->{dialect}
         or return;
@@ -113,19 +113,7 @@ sub _set_classes_for_dialect {
 
         my ( $thing, $class ) = @{$pair};
 
-        my $loaded;
-        try {
-            Class::MOP::load_class($class);
-            $loaded = 1;
-        }
-        catch {
-
-            # XXX - This is kind of broken, since a user can typo a dialect
-            # and that will just get ignored.
-            die $_ unless $_ =~ /Can't locate/;
-        };
-
-        next unless $loaded;
+        next unless load_optional_class($class);
 
         if ( exists $args->{ $thing . '_class' } ) {
             die
@@ -144,7 +132,7 @@ sub _class_name_for_dialect {
     my $dialect = shift;
     my $type    = shift;
 
-    my $suffix = join q{}, map {ucfirst} split /_/, $type;
+    my $suffix = join q{}, map { ucfirst } split /_/, $type;
 
     if ( $dialect =~ /::/ ) {
         return join '::', $dialect, $suffix;
@@ -173,11 +161,11 @@ sub parse {
         markdown => { isa => Str },
     );
 
-    $self->_clean_text(\$text);
+    $self->_clean_text( \$text );
 
     $self->_send_event('StartDocument');
 
-    $self->_block_parser()->parse_document(\$text);
+    $self->_block_parser()->parse_document( \$text );
 
     $self->_send_event('EndDocument');
 
@@ -211,7 +199,7 @@ Markdent::Parser - A markdown parser
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
