@@ -1,14 +1,14 @@
 package Markdent::Role::EventsAsMethods;
-BEGIN {
-  $Markdent::Role::EventsAsMethods::VERSION = '0.17';
+{
+  $Markdent::Role::EventsAsMethods::VERSION = '0.18';
 }
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
 use Scalar::Util qw( blessed );
 
-use namespace::autoclean;
 use Moose::Role;
 
 with 'Markdent::Role::Handler';
@@ -36,11 +36,12 @@ Markdent::Role::EventsAsMethods - Turns events into method calls
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
-This role takes a L<Markdent::Event> object and turns it into a method call.
+This role takes an object which does L<Markdent::Role::Event> role and turns
+it into a method call.
 
 =head1 METHODS
 
@@ -48,15 +49,15 @@ This role provides the following methods:
 
 =head2 $object->handle_event($event)
 
-This takes a L<Markdent::Event> object and turns it into a method call on the
-object.
+Given an object which does L<Markdent::Role::Event> role, this method makes a
+method call on C<$object> based on the event's name.
 
 The method name is the same as the value of C<< $event->event_name() >>. The
 hash reference returned by C<< $event->attributes() >> is turned into a set of
 named parameters for the method. However, any keys starting with "!" in the
 attributes will not be passed to the method.
 
-So, for example, a L<Markdown::Event::StartLink> event turns into a method
+So, for example, a L<Markdent::Event::StartLink> event turns into a method
 call like this:
 
   $handler->start_link(
