@@ -1,10 +1,11 @@
 package Markdent::Role::HTMLStream;
-BEGIN {
-  $Markdent::Role::HTMLStream::VERSION = '0.17';
+{
+  $Markdent::Role::HTMLStream::VERSION = '0.18';
 }
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
 use HTML::Stream;
 use Markdent::Types qw(
@@ -14,7 +15,6 @@ use Markdent::Types qw(
 );
 use MooseX::Params::Validate qw( validated_list validated_hash );
 
-use namespace::autoclean;
 use Moose::Role;
 
 with 'Markdent::Role::EventsAsMethods';
@@ -33,14 +33,15 @@ has _stream => (
     isa      => 'HTML::Stream',
     init_arg => undef,
     lazy     => 1,
-    default  => sub { HTML::Stream->new( $_[0]->_output() ) },
+    default  => sub { HTML::Stream->new( $_[0]->_wrapped_output() ) },
 );
 
 sub start_header {
-    my $self  = shift;
-    my ($level) = validated_list( \@_,
-                                  level => { isa => HeaderLevel },
-                                );
+    my $self = shift;
+    my ($level) = validated_list(
+        \@_,
+        level => { isa => HeaderLevel },
+    );
 
     my $tag = 'h' . $level;
 
@@ -48,10 +49,11 @@ sub start_header {
 }
 
 sub end_header {
-    my $self  = shift;
-    my ($level) = validated_list( \@_,
-                                  level => { isa => HeaderLevel },
-                                );
+    my $self = shift;
+    my ($level) = validated_list(
+        \@_,
+        level => { isa => HeaderLevel },
+    );
 
     my $tag = '_h' . $level;
 
@@ -59,49 +61,49 @@ sub end_header {
 }
 
 sub start_blockquote {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('blockquote');
 }
 
 sub end_blockquote {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_blockquote');
 }
 
 sub start_unordered_list {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('ul');
 }
 
 sub end_unordered_list {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_ul');
 }
 
 sub start_ordered_list {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('ol');
 }
 
 sub end_ordered_list {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_ol');
 }
 
 sub start_list_item {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('li');
 }
 
 sub end_list_item {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_li');
 }
@@ -118,13 +120,13 @@ sub preformatted {
 }
 
 sub start_paragraph {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('p');
 }
 
 sub end_paragraph {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_p');
 }
@@ -158,31 +160,31 @@ sub start_table_header {
 }
 
 sub end_table_header {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_thead');
 }
 
 sub start_table_body {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('tbody');
 }
 
 sub end_table_body {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_tbody');
 }
 
 sub start_table_row {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('tr');
 }
 
 sub end_table_row {
-    my $self  = shift;
+    my $self = shift;
 
     $self->_stream()->tag('_tr');
 }
@@ -253,7 +255,7 @@ sub end_code {
 
 sub auto_link {
     my $self = shift;
-    my ($uri)    = validated_list(
+    my ($uri) = validated_list(
         \@_,
         uri => { isa => Str, optional => 1 },
     );
@@ -273,7 +275,7 @@ sub start_link {
         is_implicit_id => { isa => Bool, optional => 1 },
     );
 
-    delete @p{ grep { ! defined $p{$_} } keys %p };
+    delete @p{ grep { !defined $p{$_} } keys %p };
 
     $self->_stream()->tag(
         'a', href => $p{uri},
@@ -373,7 +375,7 @@ sub image {
         is_implicit_id => { isa => Bool, optional => 1 },
     );
 
-    delete @p{ grep { ! defined $p{$_} } keys %p };
+    delete @p{ grep { !defined $p{$_} } keys %p };
 
     $self->_stream()->tag(
         'img', src => $p{uri},
@@ -388,6 +390,37 @@ sub horizontal_rule {
     $self->_stream()->tag('hr');
 }
 
+sub _wrapped_output {
+    my $self = shift;
+
+    my $output = $self->_output();
+    return $output if blessed $output && ! $output->isa('IO::Handle');
+
+    return _CheckedOutput->new($output);
+}
+
+package
+    _CheckedOutput;
+
+use strict;
+use warnings;
+
+sub new {
+    my $class  = shift;
+    my $output = shift;
+
+    return bless \$output, $class;
+}
+
+sub print {
+    my $self = shift;
+
+    # We don't need warnings from IO::* about printing to closed handles when
+    # we'll die in that case anyway.
+    no warnings 'io';
+    print { ${$self} } @_ or die "Cannot write to handle: $!";
+}
+
 1;
 
 # ABSTRACT: A role for handlers which generate HTML
@@ -402,7 +435,7 @@ Markdent::Role::HTMLStream - A role for handlers which generate HTML
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
